==> linkbox-bot-0.0.1.tgz: package/index.js <==
#!/usr/bin/env node

var program = require('commander');
var mkdirp = require('mkdirp');
var fs = require('fs');
var ncp = require('ncp').ncp;
var pkg = require('./package.json');

const version = pkg.version
const currentPath = process.cwd();

program.name('linkbox')
  .version(pkg.version, '    --version')
	.option('-p, --project_template <project_template>', 'The type of project')
  .action(function(arg) {
    	createProject(program.project_template, arg)
  }).parse(process.argv);


async function createProject(type, name) {
	let makeDirMsg = await makeDir(name);
	console.log(makeDirMsg);
	let copyTemplateMsg = await copyTemplate(name);
	console.log(copyTemplateMsg);
	let makePackageMsg = await makePackage(name);
	console.log(makePackageMsg);
}

function copyTemplate(name) {
	return new Promise((resolve, reject) => {
		ncp(currentPath + '/template', currentPath + '/' + name, function (err) {
		 	if (err) return reject(err);
		 	return resolve("Template copied successfully")
		});
	});
}

function makeDir(name) {
	return new Promise((resolve, reject) => {
		mkdirp(currentPath + '/' + name, function (err) {
    	if (err) console.error(err)
    	return resolve('Project created successfully')
		});
	});
}

function makePackage(name) {
	let package = {
	  "name": name,
	  "version": "1.0.0",
	  "description": "",
	  "main": "index.js",
	  "scripts": {
	    "start": "node build/App.js"
	  },
	  "author": "Linkbox",
	  "license": "MIT",
	  "dependencies": {
	    "@maildots/sdk": "^1.2.1",
	    "bluebird": "^3.5.0",
	    "body-parser": "^1.18.0",
	    "crypto": "^1.0.1",
	    "dotenv": "^4.0.0",
	    "express": "^4.15.4",
	    "mongodb": "^2.2.31",
	    "path": "^0.12.7"
	  },
	  "devDependencies": {
	    "@types/node": "^8.0.28"
	  },
	  "engines": {
	    "node": "8.1.4"
	  }
	}

	return new Promise((resolve, reject) => {
		fs.writeFile(currentPath + '/' + name + '/package.json', JSON.stringify(package,null,2), function(err) {
	    if(err) return reject(err);
	    return resolve("Package created successsfully");
		}); 
	});
}

==> linkbox-bot-0.0.2.tgz: package/index.js <==
#!/usr/bin/env node

var program = require('commander');
var mkdirp = require('mkdirp');
var fs = require('fs');
var ncp = require('ncp').ncp;
var pkg = require('./package.json');

const version = pkg.version
const currentPath = process.cwd();

program.name('linkbox')
  .version(pkg.version, '    --version')
	.option('-p, --project_template <project_template>', 'The type of project')
  .action(function(arg) {
    	createProject(program.project_template, arg)
  }).parse(process.argv);


async function createProject(type, name) {
	let makeDirMsg = await makeDir(name);
	console.log(makeDirMsg);
	let copyTemplateMsg = await copyTemplate(name);
	console.log(copyTemplateMsg);
	let makePackageMsg = await makePackage(name);
	console.log(makePackageMsg);
}

function copyTemplate(name) {
	console.log("DIR NAME => "__dirname);
	return new Promise((resolve, reject) => {
		ncp(__dirname + '/template', currentPath + '/' + name, function (err) {
		 	if (err) return reject(err);
		 	return resolve("Template copied successfully")
		});
	});
}

function makeDir(name) {
	return new Promise((resolve, reject) => {
		mkdirp(currentPath + '/' + name, function (err) {
    	if (err) console.error(err)
    	return resolve('Project created successfully')
		});
	});
}

function makePackage(name) {
	let package = {
	  "name": name,
	  "version": "1.0.0",
	  "description": "",
	  "main": "index.js",
	  "scripts": {
	    "start": "node build/App.js"
	  },
	  "author": "Linkbox",
	  "license": "MIT",
	  "dependencies": {
	    "@maildots/sdk": "^1.2.1",
	    "bluebird": "^3.5.0",
	    "body-parser": "^1.18.0",
	    "crypto": "^1.0.1",
	    "dotenv": "^4.0.0",
	    "express": "^4.15.4",
	    "mongodb": "^2.2.31",
	    "path": "^0.12.7"
	  },
	  "devDependencies": {
	    "@types/node": "^8.0.28"
	  },
	  "engines": {
	    "node": "8.1.4"
	  }
	}

	return new Promise((resolve, reject) => {
		fs.writeFile(currentPath + '/' + name + '/package.json', JSON.stringify(package,null,2), function(err) {
	    if(err) return reject(err);
	    return resolve("Package created successsfully");
		}); 
	});
}
